@@ -10,9 +10,9 @@
 
 #include "contactactionssettings.h"
 
-#include <kcontacts/address.h>
 #include <KDialogJobUiDelegate>
 #include <KIO/CommandLauncherJob>
+#include <kcontacts/address.h>
 
 #include <QDesktopServices>
 
@@ -20,12 +20,12 @@ using namespace Akonadi;
 
 static void replaceArguments(QString &templateStr, const KContacts::Address &address)
 {
-    templateStr.replace(QLatin1String("%s"), address.street()).
-    replace(QLatin1String("%r"), address.region()).
-    replace(QLatin1String("%l"), address.locality()).
-    replace(QLatin1String("%z"), address.postalCode()).
-    replace(QLatin1String("%n"), address.country()).
-    replace(QLatin1String("%c"), address.countryToISO(address.country()));
+    templateStr.replace(QLatin1String("%s"), address.street())
+        .replace(QLatin1String("%r"), address.region())
+        .replace(QLatin1String("%l"), address.locality())
+        .replace(QLatin1String("%z"), address.postalCode())
+        .replace(QLatin1String("%n"), address.country())
+        .replace(QLatin1String("%c"), address.countryToISO(address.country()));
 }
 
 void ShowAddressAction::showAddress(const KContacts::Address &address)
