@@ -11,11 +11,13 @@
 
 #include <QWidget>
 
-namespace KContacts {
+namespace KContacts
+{
 class Addressee;
 }
 
-namespace ContactEditor {
+namespace ContactEditor
+{
 class ContactMetaDataBase;
 
 class AbstractContactEditorWidget : public QWidget
@@ -53,7 +55,10 @@ public:
      */
     virtual void setReadOnly(bool readOnly) = 0;
 
-    virtual Q_REQUIRED_RESULT bool hasNoSavedData() const { return false; }
+    virtual Q_REQUIRED_RESULT bool hasNoSavedData() const
+    {
+        return false;
+    }
 };
 }
 
