@@ -1,7 +1,7 @@
 /*
     This file is part of Contact Editor.
 
-    SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -16,7 +16,7 @@ class MessageFormattingWidgetTest : public QObject
     Q_OBJECT
 public:
     explicit MessageFormattingWidgetTest(QObject *parent = nullptr);
-    ~MessageFormattingWidgetTest() = default;
+    ~MessageFormattingWidgetTest() override = default;
 private Q_SLOTS:
     void shouldHaveDefaultValue();
 };
