@@ -1,7 +1,7 @@
 /*
     This file is part of Contact Editor.
 
-    SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -9,12 +9,13 @@
 #ifndef MESSAGEFORMATTINGWIDGET_H
 #define MESSAGEFORMATTINGWIDGET_H
 
-#include <QWidget>
-#include <KContacts/Addressee>
 #include "contacteditor_private_export.h"
+#include <KContacts/Addressee>
+#include <QWidget>
 class QComboBox;
 class QCheckBox;
-namespace ContactEditor {
+namespace ContactEditor
+{
 class CONTACTEDITOR_TESTS_EXPORT MessageFormattingWidget : public QWidget
 {
     Q_OBJECT
