@@ -11,21 +11,24 @@
 #define WEBWIDGETLISTER_H
 
 #include "../../widgets/kwidgetlister_p.h"
-namespace KContacts {
+namespace KContacts
+{
 class Addressee;
 }
-namespace ContactEditor {
+namespace ContactEditor
+{
 class WebWidget;
 class WebWidgetLister : public KWidgetLister
 {
     Q_OBJECT
 public:
     explicit WebWidgetLister(QWidget *parent = nullptr);
-    ~WebWidgetLister();
+    ~WebWidgetLister() override;
 
     void loadContact(const KContacts::Addressee &contact);
     void storeContact(KContacts::Addressee &contact) const;
     void setReadOnly(bool readOnly);
+
 protected:
     QWidget *createWidget(QWidget *) override;
 
