@@ -1,7 +1,7 @@
 /*
     This file is part of Contact Editor.
 
-    SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -12,7 +12,8 @@
 #include <KLineEdit>
 #include <QIcon>
 class QAction;
-namespace ContactEditor {
+namespace ContactEditor
+{
 class PreferredLineEditWidget : public KLineEdit
 {
     Q_OBJECT
